#
# spec file for package ninja
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           ninja
Version:        1.6.0
Release:        7.3
Summary:        A small build system closest in spirit to Make
License:        Apache-2.0
Group:          Development/Tools/Building
Url:            https://github.com/martine/ninja
Source0:        https://github.com/martine/ninja/archive/v%{version}.tar.gz
Patch1:         ninja-disable-maxprocs-test.patch
BuildRequires:  gcc-c++
BuildRequires:  python3-base
BuildRequires:  re2c
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Ninja is yet another build system.
It takes as input the interdependencies of files (typically source code and output executables)
and orchestrates building them, quickly.

%prep
%setup -q
%patch1 -p1

%build
export CFLAGS="%{optflags}"
export CXXFLAGS="%{optflags}"
python3 ./configure.py --bootstrap --verbose

%install
mkdir -p %{buildroot}%{_bindir}

install -D -m 0755 ninja %{buildroot}%{_bindir}/ninja
install -D -m 0644 misc/zsh-completion %{buildroot}%{_datadir}/zsh/site-functions/_ninja
install -D -m 0644 misc/ninja.vim %{buildroot}%{_datadir}/vim/site/syntax/ninja.vim
install -D -m 0644 misc/bash-completion %{buildroot}%{_sysconfdir}/bash_completion.d/ninja

%check
./ninja ninja_test
./ninja_test

%files
%defattr(-,root,root)
%doc COPYING
%{_bindir}/ninja
%{_datadir}/zsh
%{_datadir}/vim
%{_sysconfdir}/bash_completion.d

%changelog
* Tue Feb 23 2016 sndirsch@suse.com
- needed for building current llvm on sle12
  (fate #315643-315645, 319159-319161, 319618)
* Sat Jan 30 2016 mpluskal@suse.com
- Update dependencies
- Use optflags when building
- Make building more verbose
* Wed Jul  1 2015 foss@grueninger.de
- Update to version 1.6.0
  * rules are now scoped to the subninja they're in.
  * dupe edges with multiple outputs now uses first edge
    instead of last (#867)
  * pools actually work now
  * generators can now run more often than twice if needed
  * unexpected output names now cause a rebuild instead of
    a hard error
  * POSIX-specific changes
  + child processes get detached from terminal
  + check for SIGINT after ppoll/pselect -> faster Ctrl-C
  + add an explicit SIGTERM signal handler
  * Ran ninja under afl-fuzz and fixed all crashes and bugs it found
  + fix crashes on cyclic graphs with multiple outputs
  + failing stat() now aborts build
  + cyclic rule bindings no longer crash
  + dependency cycles with multiple outputs no longer get
    ninja into a stuck state
- Update ninja-disable-maxprocs-test.patch to match upstream
  changes
- use Python 3 for configure
* Wed Nov 26 2014 idonmez@suse.com
- Update to version 1.5.3
  * Reaping finished subprocesses now has precedence over
    starting new jobs
  * ninja no longer depends on googletest
- Install bash/zsh completion
- Install vim syntax file
- Implement %%check
- Add ninja-disable-maxprocs-test.patch to disable max procs test,
  it needs a ulimit raise.
* Thu Sep 11 2014 idonmez@suse.com
- Only depend on python-base to trim down BuildRequires
- Do not build the html manual
- Use upstream pristine tarball
* Sun Jun 29 2014 idonmez@suse.com
- Update to version 1.5.1
  * Recompacting removes more entries from the build and deps logs.
  * Add a manifest parsing perftest and generator that generates
    random build manifests.
  * $in, $out are escaped more robustly.
  * `depfile=$out.d` now works if $out gets escaped.
  * ninja doesn't error out when it tries to create a directory and
    the directory already exists.
  * Ninja now accepts both / and \ on windows when making directories.
  * \r\n line endings are now accepted in depfiles.
  * depfile file names can now contain '{' and '}'.
  * -t compdb no longer crashes on edges with emtpy inputs.
  * 'keeprsp' is now included in the spelling suggestestions for -d
  * Many improvements to ninja-mode.el.
  * ninja_syntax.py is now faster.
  * bash completion and zsh completion provides completions more often.
  * ninja.vim now highlights $$ correctly.
* Wed Sep 18 2013 idonmez@suse.com
- Update to version 1.4.0
  * Bug fixes
- Fix version field. Its 1.x not 3.x
* Wed Jun  5 2013 idonmez@suse.com
- Update to git hash 0f53fd3
  * Version 3.0 now
  * Don't poll pipes using POLLRDHUP
  * Recompact the deps log when it gets too big
* Wed Apr 17 2013 idonmez@suse.com
- Update to git hash 7bf53c6
  * Build ninja itself in deps mode
  * Bugfixes
  * Documentation updates
* Tue Mar 12 2013 idonmez@suse.com
- Update to git hash ecc876e
  * Add compdb command to generate compile_commands.json for clang.
  * Add elapsed time (%%e) to NINJA_STATUS.
* Fri Feb 22 2013 idonmez@suse.com
- Update to git hash b26d217
  * Documentation updates
  * Fix wrong usage of std::string::find
* Thu Jan 10 2013 idonmez@suse.com
- First release
